.. Copyright (C) 2015, Kushal Das


tunir
======

Synopsis
---------

**tunir** [options]

Description
-----------

:program:`tunir` is a simple CI with a big heart. It can run predefined jobs in cloud vm(s), or in bare metal or in docker containers.


